[proxy] docs.rs← back | site home | direct (HTTPS) ↗ | proxy home | ◑ dark◐ light

AuthenticatorTransport in web_sys - Rust

Enum AuthenticatorTransport 

#[non_exhaustive]

pub enum AuthenticatorTransport { Usb = 0, Nfc = 1, Ble = 2, Internal = 3, }
The AuthenticatorTransport enum.

This API requires the following crate features to be activated: AuthenticatorTransport

This enum is marked as non-exhaustive

Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.






Source
Source
Source
Source

Converts to this type from the input type.

Source
Source

The Wasm ABI type that this converts from when coming back out from the ABI boundary.

Source

Recover a Self from Self::Abi. Read more

Source
Source

The Wasm ABI type that this converts into when crossing the ABI boundary.

Source

Convert self into Self::Abi so that it can be sent across the wasm ABI boundary.

Source
Source

Tests whether the argument is a “none” instance. If so it will be deserialized as None, and otherwise it will be passed to FromWasmAbi.

Source
Source

Returns an ABI instance indicating “none”, which JS will interpret as the None branch of this option. Read more

Source
Source

Tests for self and other values to be equal, and is used by ==.

1.0.0 · Source

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.

Source

Source

Source
Source
Source









Source
Source
Source
Source
Source

🔬This is a nightly-only experimental API. (clone_to_uninit)

Performs copy-assignment from self to dest. Read more

Source
Source

Returns the argument unchanged.

Source
Source

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U chooses to do.

Source
Source

Same as IntoWasmAbi::Abi

Source

Same as IntoWasmAbi::into_abi, except that it may throw and never return in the case of Err.

Source
Source

The resulting type after obtaining ownership.

Source

Creates owned data from borrowed data, usually by cloning. Read more

Source

Uses borrowed data to replace owned data, usually by cloning. Read more

Source
Source

The type returned in the event of a conversion error.

Source

Performs the conversion.

Source
Source

The type returned in the event of a conversion error.

Source

Performs the conversion.

Source
Source

Perform a zero-cost type-safe upcast to a wider ref type within the Wasm bindgen generics type system. Read more

Source

Perform a zero-cost type-safe upcast to a wider type within the Wasm bindgen generics type system. Read more