Enum RtcIceConnectionState
#[non_exhaustive]
pub enum RtcIceConnectionState {
New = 0,
Checking = 1,
Connected = 2,
Completed = 3,
Failed = 4,
Disconnected = 5,
Closed = 6,
}
The RtcIceConnectionState enum.
This API requires the following crate features to be activated: RtcIceConnectionState
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Converts to this type from the input type.
The Wasm ABI type that this converts from when coming back out from the
ABI boundary.
Recover a Self from Self::Abi. Read more
The Wasm ABI type that this converts into when crossing the ABI
boundary.
Convert self into Self::Abi so that it can be sent across the wasm
ABI boundary.
Tests whether the argument is a “none” instance. If so it will be
deserialized as None, and otherwise it will be passed to
FromWasmAbi.
Returns an ABI instance indicating “none”, which JS will interpret as
the None branch of this option. Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
Same as IntoWasmAbi::Abi
Same as IntoWasmAbi::into_abi, except that it may throw and never
return in the case of Err.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Perform a zero-cost type-safe upcast to a wider ref type within the Wasm
bindgen generics type system. Read more
Perform a zero-cost type-safe upcast to a wider type within the Wasm
bindgen generics type system. Read more