[proxy] docs.rs← back | site home | direct (HTTPS) ↗ | proxy home | ◑ dark◐ light

KeyboardEventInit in web_sys - Rust

Struct KeyboardEventInit 

pub struct KeyboardEventInit { /* private fields */ }
The KeyboardEventInit dictionary.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the bubbles field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the bubbles field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the cancelable field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the cancelable field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the composed field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the composed field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the detail field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the detail field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the view field of this object.

This API requires the following crate features to be activated: KeyboardEventInit, Window

Source
Change the view field of this object.

This API requires the following crate features to be activated: KeyboardEventInit, Window

Source
Get the altKey field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the altKey field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the ctrlKey field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the ctrlKey field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the metaKey field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the metaKey field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierAltGraph field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierAltGraph field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierCapsLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierCapsLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierFn field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierFn field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierFnLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierFnLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierNumLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierNumLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierOS field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierOS field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierScrollLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierScrollLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierSymbol field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierSymbol field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the modifierSymbolLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the modifierSymbolLock field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the shiftKey field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the shiftKey field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the charCode field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the charCode field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the code field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the code field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the isComposing field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the isComposing field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the key field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the key field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the keyCode field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the keyCode field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the location field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the location field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the repeat field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the repeat field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Get the which field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Change the which field of this object.

This API requires the following crate features to be activated: KeyboardEventInit

Source
Construct a new KeyboardEventInit.

This API requires the following crate features to be activated: KeyboardEventInit

👎Deprecated: Use set_bubbles() instead.

👎Deprecated: Use set_cancelable() instead.

👎Deprecated: Use set_composed() instead.

👎Deprecated: Use set_detail() instead.

👎Deprecated: Use set_view() instead.

👎Deprecated: Use set_alt_key() instead.

👎Deprecated: Use set_ctrl_key() instead.

👎Deprecated: Use set_meta_key() instead.

👎Deprecated: Use set_modifier_alt_graph() instead.

👎Deprecated: Use set_modifier_caps_lock() instead.

👎Deprecated: Use set_modifier_fn() instead.

👎Deprecated: Use set_modifier_fn_lock() instead.

👎Deprecated: Use set_modifier_num_lock() instead.

👎Deprecated: Use set_modifier_os() instead.

👎Deprecated: Use set_modifier_scroll_lock() instead.

👎Deprecated: Use set_modifier_symbol() instead.

👎Deprecated: Use set_modifier_symbol_lock() instead.

👎Deprecated: Use set_shift_key() instead.

👎Deprecated: Use set_char_code() instead.

👎Deprecated: Use set_code() instead.

👎Deprecated: Use set_is_composing() instead.

👎Deprecated: Use set_key() instead.

👎Deprecated: Use set_key_code() instead.

👎Deprecated: Use set_location() instead.

👎Deprecated: Use set_repeat() instead.

👎Deprecated: Use set_which() instead.

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

👎Deprecated: Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Returns the f64 value of this JS value if it’s an instance of a number.

If this JS value is not an instance of a number then this returns None.

Tests whether this JS value is a JS string.

If this JS value is a string value, this function copies the JS string value into Wasm linear memory, encoded as UTF-8, and returns it as a Rust String.

To avoid the copying and re-encoding, consider the JsString::try_from() function from js-sys instead.

If this JS value is not an instance of a string or if it’s not valid utf-8 then this returns None.

UTF-16 vs UTF-8

JavaScript strings in general are encoded as UTF-16, but Rust strings are encoded as UTF-8. This can cause the Rust string to look a bit different than the JS string sometimes. For more details see the documentation about the str type which contains a few caveats about the encodings.

Returns the bool value of this JS value if it’s an instance of a boolean.

If this JS value is not an instance of a boolean then this returns None.

Tests whether this JS value is null

Tests whether this JS value is undefined

Tests whether this JS value is null or undefined

Tests whether the type of this JS value is symbol

Tests whether typeof self == "object" && self !== null.

Tests whether this JS value is an instance of Array.

Tests whether the type of this JS value is function.

Tests whether the type of this JS value is bigint.

Tests whether the value is “truthy”.

Tests whether the value is “falsy”.

Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.

MDN documentation

Source
Source

Converts this type into a shared reference of the (usually inferred) input type.

Source
Source

Converts this type into a shared reference of the (usually inferred) input type.

Source
Source

Converts this type into a shared reference of the (usually inferred) input type.

Source
Source
Source
Source
Source

The resulting type after dereferencing.

Source

Dereferences the value.

Source
Source

The singular concrete type that all generic variants can be transmuted on

Source
Source

Converts to this type from the input type.

Source
Source

Converts to this type from the input type.

Source
Source

Converts to this type from the input type.

Source
Source

The Wasm ABI type that this converts from when coming back out from the ABI boundary.

Source

Recover a Self from Self::Abi. Read more

Source
Source

The Wasm ABI type that this converts into when crossing the ABI boundary.

Source

Convert self into Self::Abi so that it can be sent across the wasm ABI boundary.

Source
Source

The Wasm ABI type that this converts into when crossing the ABI boundary.

Source

Convert self into Self::Abi so that it can be sent across the wasm ABI boundary.

Source
Source

Performs a dynamic instanceof check to see whether the JsValue provided is an instance of this type. Read more

Source

Performs a zero-cost unchecked conversion from a JsValue into an instance of Self Read more

Source

Performs a zero-cost unchecked conversion from a &JsValue into an instance of &Self. Read more

Source

Test whether this JS value has a type T. Read more

Source

Performs a dynamic cast (checked at runtime) of this value into the target type T. Read more

Source

Performs a dynamic cast (checked at runtime) of this value into the target type T. Read more

Source

Performs a zero-cost unchecked cast into the specified type. Read more

Source

Performs a zero-cost unchecked cast into a reference to the specified type. Read more

Source

Test whether this JS value is an instance of the type T. Read more

Source

Performs a dynamic check to see whether the JsValue provided is a value of this type. Read more

Source
Source

Same as RefFromWasmAbi::Abi

Source

Same as RefFromWasmAbi::Anchor

Source

Same as RefFromWasmAbi::ref_from_abi

Source
Source

Tests whether the argument is a “none” instance. If so it will be deserialized as None, and otherwise it will be passed to FromWasmAbi.

Source
Source

Returns an ABI instance indicating “none”, which JS will interpret as the None branch of this option. Read more

Source
Source

Returns an ABI instance indicating “none”, which JS will interpret as the None branch of this option. Read more

Source
Source

Tests for self and other values to be equal, and is used by ==.

1.0.0 · Source

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.

Source
Source

The type that this value resolves to.

Source
Source

The Wasm ABI type references to Self are recovered from.

Source

The type that holds the reference to Self for the duration of the invocation of the function that has an &Self parameter. This is required to ensure that the lifetimes don’t persist beyond one function call, and so that they remain anonymous.

Source

Recover a Self::Anchor from Self::Abi. Read more

Source

Source

Source
Source
Source
Source
Source
Source
Source