pub struct KeyframeAnimationOptions { /* private fields */ }Expand description
The KeyframeAnimationOptions dictionary.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the delay field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the delay field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the direction field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions, PlaybackDirection
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the direction field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions, PlaybackDirection
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the duration field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the duration field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the duration field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the easing field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the easing field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the endDelay field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the endDelay field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the fill field of this object.
This API requires the following crate features to be activated: FillMode, KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the fill field of this object.
This API requires the following crate features to be activated: FillMode, KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the iterationStart field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the iterationStart field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the iterations field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the iterations field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the composite field of this object.
This API requires the following crate features to be activated: CompositeOperation, KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the composite field of this object.
This API requires the following crate features to be activated: CompositeOperation, KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the iterationComposite field of this object.
This API requires the following crate features to be activated: IterationCompositeOperation, KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the iterationComposite field of this object.
This API requires the following crate features to be activated: IterationCompositeOperation, KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the id field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the id field of this object.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Get the timeline field of this object.
This API requires the following crate features to be activated: AnimationTimeline, KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Change the timeline field of this object.
This API requires the following crate features to be activated: AnimationTimeline, KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Source
Construct a new KeyframeAnimationOptions.
This API requires the following crate features to be activated: KeyframeAnimationOptions
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
👎Deprecated: Use set_delay() instead.
👎Deprecated: Use set_direction() instead.
👎Deprecated: Use set_duration() instead.
👎Deprecated: Use set_easing() instead.
👎Deprecated: Use set_end_delay() instead.
👎Deprecated: Use set_fill() instead.
👎Deprecated: Use set_iteration_start() instead.
👎Deprecated: Use set_iterations() instead.
👎Deprecated: Use set_composite() instead.
👎Deprecated: Use set_iteration_composite() instead.
👎Deprecated: Use set_id() instead.
👎Deprecated: Use set_timeline() instead.
The constructor property returns a reference to the Object constructor
function that created the instance object.
Source 👎Deprecated: Use Object::hasOwn instead.
Object::hasOwn instead.The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
The valueOf() method returns the primitive value of the
specified object.
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Tests whether this JS value is a JS string.
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Tests whether this JS value is null
Tests whether this JS value is undefined
Tests whether this JS value is null or undefined
Tests whether the type of this JS value is symbol
Tests whether typeof self == "object" && self !== null.
Tests whether this JS value is an instance of Array.
Tests whether the type of this JS value is function.
Tests whether the type of this JS value is bigint.
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.