pub struct ListBoxObject { /* private fields */ }Expand description
The ListBoxObject class.
This API requires the following crate features to be activated: ListBoxObject
The constructor property returns a reference to the Object constructor
function that created the instance object.
Source ๐Deprecated: Use Object::hasOwn instead.
Object::hasOwn instead.The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
The isPrototypeOf() method checks if an object exists in another
objectโs prototype chain.
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
The valueOf() method returns the primitive value of the
specified object.
Returns the f64 value of this JS value if itโs an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Tests whether this JS value is a JS string.
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if itโs not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Returns the bool value of this JS value if itโs an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Tests whether this JS value is null
Tests whether this JS value is undefined
Tests whether this JS value is null or undefined
Tests whether the type of this JS value is symbol
Tests whether typeof self == "object" && self !== null.
Tests whether this JS value is an instance of Array.
Tests whether the type of this JS value is function.
Tests whether the type of this JS value is bigint.
Tests whether the value is โtruthyโ.
Tests whether the value is โfalsyโ.
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Source
Source
Performs a dynamic instanceof check to see whether the JsValue
provided is an instance of this type. Read more
Source
Performs a dynamic check to see whether the JsValue provided
is a value of this type. Read more
Source
Performs a zero-cost unchecked conversion from a &JsValue into an
instance of &Self. Read more
Source
Performs a dynamic cast (checked at runtime) of this value into the
target type T. Read more