pub struct RtcOutboundRtpStreamStats { /* private fields */ }Expand description
The RtcOutboundRtpStreamStats dictionary.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the id field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the id field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the timestamp field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the timestamp field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the type field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats, RtcStatsType
Source
Change the type field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats, RtcStatsType
Source
Get the bitrateMean field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the bitrateMean field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the bitrateStdDev field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the bitrateStdDev field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the codecId field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the codecId field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the firCount field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the firCount field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the framerateMean field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the framerateMean field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the framerateStdDev field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the framerateStdDev field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the isRemote field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the isRemote field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the mediaTrackId field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the mediaTrackId field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the mediaType field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the mediaType field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the nackCount field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the nackCount field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the pliCount field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the pliCount field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the remoteId field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the remoteId field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the ssrc field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the ssrc field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the transportId field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the transportId field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the bytesSent field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the bytesSent field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the bytesSent field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the bytesSent field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the droppedFrames field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the droppedFrames field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the framesEncoded field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the framesEncoded field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the packetsSent field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the packetsSent field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Get the targetBitrate field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Change the targetBitrate field of this object.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
Source
Construct a new RtcOutboundRtpStreamStats.
This API requires the following crate features to be activated: RtcOutboundRtpStreamStats
👎Deprecated: Use set_id() instead.
👎Deprecated: Use set_timestamp() instead.
👎Deprecated: Use set_type() instead.
👎Deprecated: Use set_bitrate_mean() instead.
👎Deprecated: Use set_bitrate_std_dev() instead.
👎Deprecated: Use set_codec_id() instead.
👎Deprecated: Use set_fir_count() instead.
👎Deprecated: Use set_framerate_mean() instead.
👎Deprecated: Use set_framerate_std_dev() instead.
👎Deprecated: Use set_is_remote() instead.
👎Deprecated: Use set_media_track_id() instead.
👎Deprecated: Use set_media_type() instead.
👎Deprecated: Use set_nack_count() instead.
👎Deprecated: Use set_pli_count() instead.
👎Deprecated: Use set_remote_id() instead.
👎Deprecated: Use set_ssrc() instead.
👎Deprecated: Use set_transport_id() instead.
👎Deprecated: Use set_bytes_sent() instead.
👎Deprecated: Use set_dropped_frames() instead.
👎Deprecated: Use set_frames_encoded() instead.
👎Deprecated: Use set_packets_sent() instead.
👎Deprecated: Use set_target_bitrate() instead.
The constructor property returns a reference to the Object constructor
function that created the instance object.
Source 👎Deprecated: Use Object::hasOwn instead.
Object::hasOwn instead.The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
The valueOf() method returns the primitive value of the
specified object.
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Tests whether this JS value is a JS string.
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Tests whether this JS value is null
Tests whether this JS value is undefined
Tests whether this JS value is null or undefined
Tests whether the type of this JS value is symbol
Tests whether typeof self == "object" && self !== null.
Tests whether this JS value is an instance of Array.
Tests whether the type of this JS value is function.
Tests whether the type of this JS value is bigint.
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.