pub struct Text { /* private fields */ }Expand description
The Text class.
This API requires the following crate features to be activated: Text
Source
Getter for the wholeText field of this object.
This API requires the following crate features to be activated: Text
Source
Getter for the assignedSlot field of this object.
This API requires the following crate features to be activated: HtmlSlotElement, Text
Source
The new Text(..) constructor, creating a new instance of Text.
This API requires the following crate features to be activated: Text
Source
The new Text(..) constructor, creating a new instance of Text.
This API requires the following crate features to be activated: Text
Source
The splitText() method.
This API requires the following crate features to be activated: Text
Source
The convertPointFromNode() method.
This API requires the following crate features to be activated: DomPoint, DomPointInit, Text
Source
The convertPointFromNode() method.
This API requires the following crate features to be activated: DomPoint, DomPointInit, Element, Text
Source
The convertPointFromNode() method.
This API requires the following crate features to be activated: Document, DomPoint, DomPointInit, Text
Source
The convertPointFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, DomPoint, DomPointInit, Text
Source
The convertPointFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, DomPoint, DomPointInit, Element, Text
Source
The convertPointFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, Document, DomPoint, DomPointInit, Text
Source
The convertQuadFromNode() method.
This API requires the following crate features to be activated: DomQuad, Text
Source
The convertQuadFromNode() method.
This API requires the following crate features to be activated: DomQuad, Element, Text
Source
The convertQuadFromNode() method.
This API requires the following crate features to be activated: Document, DomQuad, Text
Source
The convertQuadFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, DomQuad, Text
Source
The convertQuadFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, DomQuad, Element, Text
Source
The convertQuadFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, Document, DomQuad, Text
Source
The convertRectFromNode() method.
This API requires the following crate features to be activated: DomQuad, DomRectReadOnly, Text
Source
The convertRectFromNode() method.
This API requires the following crate features to be activated: DomQuad, DomRectReadOnly, Element, Text
Source
The convertRectFromNode() method.
This API requires the following crate features to be activated: Document, DomQuad, DomRectReadOnly, Text
Source
The convertRectFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, DomQuad, DomRectReadOnly, Text
Source
The convertRectFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, DomQuad, DomRectReadOnly, Element, Text
Source
The convertRectFromNode() method.
This API requires the following crate features to be activated: ConvertCoordinateOptions, Document, DomQuad, DomRectReadOnly, Text
Source
The getBoxQuads() method.
This API requires the following crate features to be activated: Text
Getter for the data field of this object.
This API requires the following crate features to be activated: CharacterData
Setter for the data field of this object.
This API requires the following crate features to be activated: CharacterData
Getter for the length field of this object.
This API requires the following crate features to be activated: CharacterData
Getter for the previousElementSibling field of this object.
This API requires the following crate features to be activated: CharacterData, Element
Getter for the nextElementSibling field of this object.
This API requires the following crate features to be activated: CharacterData, Element
The appendData() method.
This API requires the following crate features to be activated: CharacterData
The deleteData() method.
This API requires the following crate features to be activated: CharacterData
The insertData() method.
This API requires the following crate features to be activated: CharacterData
The replaceData() method.
This API requires the following crate features to be activated: CharacterData
The substringData() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The after() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The before() method.
This API requires the following crate features to be activated: CharacterData
The remove() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Getter for the nodeType field of this object.
This API requires the following crate features to be activated: Node
Getter for the nodeName field of this object.
This API requires the following crate features to be activated: Node
Getter for the baseURI field of this object.
This API requires the following crate features to be activated: Node
Getter for the isConnected field of this object.
This API requires the following crate features to be activated: Node
Getter for the ownerDocument field of this object.
This API requires the following crate features to be activated: Document, Node
Getter for the parentNode field of this object.
This API requires the following crate features to be activated: Node
Getter for the parentElement field of this object.
This API requires the following crate features to be activated: Element, Node
Getter for the childNodes field of this object.
This API requires the following crate features to be activated: Node, NodeList
Getter for the firstChild field of this object.
This API requires the following crate features to be activated: Node
Getter for the lastChild field of this object.
This API requires the following crate features to be activated: Node
Getter for the previousSibling field of this object.
This API requires the following crate features to be activated: Node
Getter for the nextSibling field of this object.
This API requires the following crate features to be activated: Node
Getter for the nodeValue field of this object.
This API requires the following crate features to be activated: Node
Setter for the nodeValue field of this object.
This API requires the following crate features to be activated: Node
Getter for the textContent field of this object.
This API requires the following crate features to be activated: Node
Setter for the textContent field of this object.
This API requires the following crate features to be activated: Node
The appendChild() method.
This API requires the following crate features to be activated: Node
The cloneNode() method.
This API requires the following crate features to be activated: Node
The cloneNode() method.
This API requires the following crate features to be activated: Node
The compareDocumentPosition() method.
This API requires the following crate features to be activated: Node
The contains() method.
This API requires the following crate features to be activated: Node
The getRootNode() method.
This API requires the following crate features to be activated: Node
The getRootNode() method.
This API requires the following crate features to be activated: GetRootNodeOptions, Node
The hasChildNodes() method.
This API requires the following crate features to be activated: Node
The insertBefore() method.
This API requires the following crate features to be activated: Node
The isDefaultNamespace() method.
This API requires the following crate features to be activated: Node
The isEqualNode() method.
This API requires the following crate features to be activated: Node
The isSameNode() method.
This API requires the following crate features to be activated: Node
The lookupNamespaceURI() method.
This API requires the following crate features to be activated: Node
The lookupPrefix() method.
This API requires the following crate features to be activated: Node
The normalize() method.
This API requires the following crate features to be activated: Node
The removeChild() method.
This API requires the following crate features to be activated: Node
The replaceChild() method.
This API requires the following crate features to be activated: Node
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
The removeEventListener() method.
This API requires the following crate features to be activated: EventListenerOptions, EventTarget
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
The constructor property returns a reference to the Object constructor
function that created the instance object.
Source 👎Deprecated: Use Object::hasOwn instead.
Object::hasOwn instead.The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
The valueOf() method returns the primitive value of the
specified object.
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Tests whether this JS value is a JS string.
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Tests whether this JS value is null
Tests whether this JS value is undefined
Tests whether this JS value is null or undefined
Tests whether the type of this JS value is symbol
Tests whether typeof self == "object" && self !== null.
Tests whether this JS value is an instance of Array.
Tests whether the type of this JS value is function.
Tests whether the type of this JS value is bigint.
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.