Get the cmd field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the cmd field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the curExternalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the curExternalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the curInternalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the curInternalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the dns1 field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the dns1 field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the dns1_long field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the dns1_long field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the dns2 field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the dns2 field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the dns2_long field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the dns2_long field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the dnses field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the dnses field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the domain field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the domain field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the enable field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the enable field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the enabled field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the enabled field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the endIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the endIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the externalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the externalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the gateway field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the gateway field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the gateway_long field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the gateway_long field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the gateways field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the gateways field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the id field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the id field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the ifname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the ifname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the interfaceList field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the interfaceList field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the internalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the internalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the ip field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the ip field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the ipaddr field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the ipaddr field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the key field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the key field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the link field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the link field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the mask field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the mask field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the maskLength field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the maskLength field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the mode field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the mode field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the mtu field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the mtu field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the preExternalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the preExternalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the preInternalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the preInternalIfname field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the prefix field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the prefix field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the prefixLength field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the prefixLength field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the report field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the report field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the security field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the security field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the serverIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the serverIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the ssid field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the ssid field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the startIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the startIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the threshold field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the threshold field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the threshold field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the threshold field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the usbEndIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the usbEndIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the usbStartIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the usbStartIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the wifiEndIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the wifiEndIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the wifiStartIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the wifiStartIp field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Get the wifictrlinterfacename field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Change the wifictrlinterfacename field of this object.
This API requires the following crate features to be activated: NetworkCommandOptions
Construct a new NetworkCommandOptions.
This API requires the following crate features to be activated: NetworkCommandOptions
👎Deprecated: Use set_cmd() instead.
👎Deprecated: Use set_cur_external_ifname() instead.
👎Deprecated: Use set_cur_internal_ifname() instead.
👎Deprecated: Use set_dns1() instead.
👎Deprecated: Use set_dns1_long() instead.
👎Deprecated: Use set_dns2() instead.
👎Deprecated: Use set_dns2_long() instead.
👎Deprecated: Use set_dnses() instead.
👎Deprecated: Use set_domain() instead.
👎Deprecated: Use set_enable() instead.
👎Deprecated: Use set_enabled() instead.
👎Deprecated: Use set_end_ip() instead.
👎Deprecated: Use set_external_ifname() instead.
👎Deprecated: Use set_gateway() instead.
👎Deprecated: Use set_gateway_long() instead.
👎Deprecated: Use set_gateways() instead.
👎Deprecated: Use set_id() instead.
👎Deprecated: Use set_ifname() instead.
👎Deprecated: Use set_interface_list() instead.
👎Deprecated: Use set_internal_ifname() instead.
👎Deprecated: Use set_ip() instead.
👎Deprecated: Use set_ipaddr() instead.
👎Deprecated: Use set_key() instead.
👎Deprecated: Use set_link() instead.
👎Deprecated: Use set_mask() instead.
👎Deprecated: Use set_mask_length() instead.
👎Deprecated: Use set_mode() instead.
👎Deprecated: Use set_mtu() instead.
👎Deprecated: Use set_pre_external_ifname() instead.
👎Deprecated: Use set_pre_internal_ifname() instead.
👎Deprecated: Use set_prefix() instead.
👎Deprecated: Use set_prefix_length() instead.
👎Deprecated: Use set_report() instead.
👎Deprecated: Use set_security() instead.
👎Deprecated: Use set_server_ip() instead.
👎Deprecated: Use set_ssid() instead.
👎Deprecated: Use set_start_ip() instead.
👎Deprecated: Use set_threshold() instead.
👎Deprecated: Use set_usb_end_ip() instead.
👎Deprecated: Use set_usb_start_ip() instead.
👎Deprecated: Use set_wifi_end_ip() instead.
👎Deprecated: Use set_wifi_start_ip() instead.
👎Deprecated: Use set_wifictrlinterfacename() instead.